@@ -41,10 +41,10 @@ convertBMRToRankMatrix = function(bmr, measure = NULL, ties.method = "average",
   df[, "alg.rank" := rank(.SD$x, ties.method = ties.method), by = "task.id"] # nolint FIXME: find out what `:=` looks like in the AST and adjust the linter
 
   # convert into matrix, rows = leaner, cols = tasks
-  df = melt(setDF(df), c("task.id", "learner.id"), "alg.rank")
+  df = melt(df, c("task.id", "learner.id"), "alg.rank")
   df = dcast(df, learner.id ~ task.id)
   task.id.names = setdiff(colnames(df), "learner.id")
-  mat = as.matrix(df[, task.id.names])
+  mat = as.matrix(setDF(df)[, task.id.names])
   rownames(mat) = df$learner.id
   colnames(mat) = task.id.names
   return(mat)
