@@ -1,10 +1,6 @@
 context("benchmark")
 
 test_that("benchmark", {
-  if (getRversion() > "3.5.3") {
-    suppressWarnings(RNGversion("3.5.0"))
-  }
-
   set.seed(getOption("mlr.debug.seed"))
 
   task.names = c("binary", "multiclass")
@@ -13,7 +9,8 @@ test_that("benchmark", {
   learners = lapply(learner.names, makeLearner)
   rin = makeResampleDesc("CV", iters = 2L)
 
-  res = benchmark(learners = makeLearner("classif.lda", predict.type = "prob"), task = binaryclass.task, resampling = rin)
+  res = benchmark(learners = makeLearner("classif.lda", predict.type = "prob"),
+    task = binaryclass.task, resamplings = rin)
   preds = getBMRPredictions(res, as.df = FALSE)
   expect_true(is.list(preds))
   expect_true(setequal(names(preds), "binary"))
@@ -34,7 +31,8 @@ test_that("benchmark", {
 
   df = as.data.frame(res)
   expect_true(is.data.frame(df))
-  expect_equal(dim(df), c(rin$iters * length(task.names) * length(learner.names), 4L))
+  expect_equal(dim(df), c(rin$iters * length(task.names) *
+    length(learner.names), 4L))
   expect_true(setequal(df$task.id, task.names))
   expect_true(setequal(df$learner.id, learner.names))
   expect_true(is.numeric(df$mmce))
@@ -54,7 +52,8 @@ test_that("benchmark", {
 
   preds = getBMRPredictions(res, as.df = TRUE)
   expect_is(preds, "data.frame")
-  expect_equal(nrow(preds), 2 * (getTaskSize(multiclass.task) + getTaskSize(binaryclass.task)))
+  expect_equal(nrow(preds), 2 * (getTaskSize(multiclass.task) +
+    getTaskSize(binaryclass.task)))
 
   p = getBMRPerformances(res, as.df = TRUE)
   expect_is(p, "data.frame")
@@ -66,23 +65,28 @@ test_that("benchmark", {
 
   # make it more complex
   ps = makeParamSet(makeDiscreteLearnerParam("cp", values = c(0.01, 0.1)))
-  learner.names = c("classif.lda", "classif.rpart", "classif.lda.featsel", "classif.rpart.tuned", "classif.lda.filtered")
-  learners = list(makeLearner("classif.lda"), makeLearner("classif.rpart"))
+  learner.names = c("classif.lda", "classif.rpart", "classif.lda.featsel",
+    "classif.rpart.tuned", "classif.lda.filtered")
+  learners = list(makeLearner("classif.lda"),
+    makeLearner("classif.rpart"))
   learners = c(learners, list(
-    makeFeatSelWrapper(learners[[1L]], resampling = rin, control = makeFeatSelControlRandom(maxit = 3)),
-    makeTuneWrapper(learners[[2L]], resampling = rin, par.set = ps, control = makeTuneControlGrid()),
+    makeFeatSelWrapper(learners[[1L]], resampling = rin,
+      control = makeFeatSelControlRandom(maxit = 3)),
+    makeTuneWrapper(learners[[2L]], resampling = rin, par.set = ps,
+      control = makeTuneControlGrid()),
     makeFilterWrapper(learners[[1L]], fw.perc = 0.5)
   ))
   resamplings = list(rin, makeResampleDesc("Bootstrap", iters = 2L))
   measures = list(mmce, acc)
 
-  res = benchmark(learners = learners, tasks = tasks, resamplings = resamplings, measures = measures,
-    keep.extract = TRUE)
+  res = benchmark(learners = learners, tasks = tasks, resamplings = resamplings,
+    measures = measures, keep.extract = TRUE)
   expect_true("BenchmarkResult" %in% class(res))
 
   df = as.data.frame(res)
   expect_true(is.data.frame(df))
-  expect_equal(dim(df), c(rin$iters * length(task.names) * length(learner.names), 5L))
+  expect_equal(dim(df), c(rin$iters * length(task.names) *
+    length(learner.names), 5L))
   expect_true(setequal(df$task.id, task.names))
   expect_true(setequal(df$learner.id, learner.names))
   expect_true(is.numeric(df$mmce))
@@ -126,8 +130,8 @@ test_that("benchmark", {
   expect_is(trd, "data.frame")
   expect_equal(ncol(trd), 5)
   expect_equal(nrow(trd), 4)
-  expect_equal(unique(trd$task.id), factor(task.names))
-  expect_equal(unique(trd$learner.id), factor("classif.rpart.tuned"))
+  expect_equal(levels(as.factor(trd$task.id)), task.names)
+  expect_equal(levels(as.factor(trd$learner.id)), "classif.rpart.tuned")
   expect_equal(unique(trd$iter), 1:2)
 
   tf = getBMRFeatSelResults(res, as.df = FALSE)
@@ -145,9 +149,9 @@ test_that("benchmark", {
   tfd = getBMRFeatSelResults(res, as.df = TRUE)
   expect_is(tfd, "data.frame")
   expect_equal(ncol(tfd), 4)
-  expect_equal(nrow(tfd), 61)
-  expect_equal(unique(tfd$task.id), factor(task.names))
-  expect_equal(unique(tfd$learner.id), factor("classif.lda.featsel"))
+  expect_gt(nrow(tfd), 10)
+  expect_equal(levels(as.factor(tfd$task.id)), task.names)
+  expect_equal(levels(as.factor(tfd$learner.id)), "classif.lda.featsel")
   expect_equal(unique(tfd$iter), 1:2)
 
   tff = getBMRFilteredFeatures(res, as.df = FALSE)
@@ -166,8 +170,8 @@ test_that("benchmark", {
   expect_is(tffd, "data.frame")
   expect_equal(ncol(tffd), 4)
   expect_equal(nrow(tffd), 64)
-  expect_equal(unique(tffd$task.id), factor(task.names))
-  expect_equal(unique(tffd$learner.id), factor("classif.lda.filtered"))
+  expect_equal(levels(as.factor(tffd$task.id)), task.names)
+  expect_equal(levels(as.factor(tffd$learner.id)), "classif.lda.filtered")
   expect_equal(unique(tffd$iter), 1:2)
 
   f = function(tmp, cl) {
@@ -195,7 +199,8 @@ test_that("keep.preds and models are passed down to resample()", {
   learners = lapply(learner.names, makeLearner)
   rin = makeResampleDesc("CV", iters = 2L)
 
-  res = benchmark(learners = makeLearner("classif.lda", predict.type = "prob"), task = binaryclass.task, resampling = rin, keep.pred = TRUE, models = TRUE)
+  res = benchmark(learners = makeLearner("classif.lda", predict.type = "prob"),
+    task = binaryclass.task, resampling = rin, keep.pred = TRUE, models = TRUE)
   x = res$results$binary$classif.lda
   expect_is(x, "ResampleResult")
   expect_list(x$models, types = "WrappedModel")
@@ -214,7 +219,9 @@ test_that("keep.preds and models are passed down to resample()", {
   models111 = models11[[1L]]
   expect_is(models111, "WrappedModel")
 
-  res = benchmark(learners = makeLearner("classif.lda", predict.type = "prob"), task = binaryclass.task, resampling = rin, keep.pred = FALSE, models = FALSE)
+  res = benchmark(learners = makeLearner("classif.lda", predict.type = "prob"),
+    task = binaryclass.task, resampling = rin, keep.pred = FALSE,
+    models = FALSE)
   x = res$results$binary$classif.lda
   models11 = getBMRModels(res)[[1L]][[1L]]
   expect_is(x, "ResampleResult")
@@ -237,22 +244,25 @@ test_that("drop option works for BenchmarkResults_operators", {
   tasks = list(binaryclass.task, multiclass.task)
   learner.names = c("classif.lda", "classif.rpart")
   learners = lapply(learner.names, makeLearner)
-  two.two = benchmark(learners = learners, task = tasks, resampling = hout)
-  two.one = benchmark(learners = learners[[1L]], task = tasks, resampling = hout)
-  one.two = benchmark(learners = learners, task = tasks[[1L]], resampling = hout)
-  one.one = benchmark(learners = learners[[1L]], task = tasks[[1L]], resampling = hout)
+  two_two = benchmark(learners = learners, task = tasks, resampling = hout)
+  two_one = benchmark(learners = learners[[1L]], task = tasks,
+    resampling = hout)
+  one_two = benchmark(learners = learners, task = tasks[[1L]],
+    resampling = hout)
+  one_one = benchmark(learners = learners[[1L]], task = tasks[[1L]],
+    resampling = hout)
 
-  # check behaviour extensively
-  res = getBMRPredictions(two.two, drop = TRUE)
+  # check behavior extensively
+  res = getBMRPredictions(two_two, drop = TRUE)
   expect_true(all(names(res) == task.names))
 
-  res = getBMRPredictions(two.one, drop = TRUE)
+  res = getBMRPredictions(two_one, drop = TRUE)
   expect_true(all(names(res) == task.names))
 
-  res = getBMRPredictions(one.two, drop = TRUE)
+  res = getBMRPredictions(one_two, drop = TRUE)
   expect_true(all(names(res) == learner.names))
 
-  res = getBMRPredictions(one.one, drop = TRUE)
+  res = getBMRPredictions(one_one, drop = TRUE)
   expect_class(res, "Prediction")
 
   # check all other functions that use 'drop' briefly
@@ -262,13 +272,13 @@ test_that("drop option works for BenchmarkResults_operators", {
     expect_true(all(names(res) == new.names))
   }
 
-  funs.to.test = c(getBMRPerformances, getBMRTuneResults,
+  funs_to_test = c(getBMRPerformances, getBMRTuneResults,
     getBMRFeatSelResults, getBMRFilteredFeatures, getBMRModels)
-  lapply(funs.to.test, FUN = testDropOption, bmr = one.two,
+  lapply(funs_to_test, FUN = testDropOption, bmr = one_two,
     new.names = learner.names)
 
-  # getBMROptResults needs seperate checking since it needs extra argument
-  testDropOption(one.two, getBMROptResults, new.names = learner.names,
+  # getBMROptResults needs separate checking since it needs extra argument
+  testDropOption(one_two, getBMROptResults, new.names = learner.names,
     wrapper.class = "cl")
 })
 
@@ -288,10 +298,10 @@ test_that("benchmark works with ensemble filters", {
   task.names = c("binary", "multiclass")
   tasks = list(binaryclass.task, multiclass.task)
   rin = makeResampleDesc("CV", iters = 2L)
-  tune_ctrl = makeTuneControlRandom(maxit = 3)
+  tune.ctrl = makeTuneControlRandom(maxit = 3)
 
   tune_wrapper_svm = makeTuneWrapper(lrn, resampling = rin, par.set = par.set,
-    control = tune_ctrl, show.info = FALSE,
+    control = tune.ctrl, show.info = FALSE,
     measures = list(acc))
 
   expect_class(benchmark(learners = tune_wrapper_svm, task = tasks,
@@ -300,11 +310,15 @@ test_that("benchmark works with ensemble filters", {
 })
 test_that("benchmark handles failure models correctly", {
 
+  # RWeka not avail
+  skip_on_cran()
+  skip_on_os("windows")
+
   # Define task
   task = binaryclass.task
 
   # Define filter parameter set
-  filter_ps = makeParamSet(makeIntegerParam("fw.abs", lower = 1,
+  filter.ps = makeParamSet(makeIntegerParam("fw.abs", lower = 1,
     upper = getTaskNFeats(task)))
 
   # Define tuning control
@@ -317,32 +331,40 @@ test_that("benchmark handles failure models correctly", {
   # Define learner
   quiet_learner = makeLearner("classif.__mlrmocklearners__3",
     config = list("on.learner.error" = "quiet"))
-  quiet_learner = makeFilterWrapper(quiet_learner, fw.method = "FSelector_chi.squared")
+  quiet_learner = makeFilterWrapper(quiet_learner,
+    fw.method = "FSelector_chi.squared")
 
-  quiet_learner = makeTuneWrapper(quiet_learner, resampling = inner, control = ctrl,
-    par.set = filter_ps, show.info = TRUE)
+  quiet_learner = makeTuneWrapper(quiet_learner, resampling = inner,
+    control = ctrl,
+    par.set = filter.ps, show.info = TRUE)
 
-  stop_learner = makeLearner("classif.__mlrmocklearners__3",
+  stop.learner = makeLearner("classif.__mlrmocklearners__3",
     config = list("on.learner.error" = "stop"))
-  stop_learner = makeFilterWrapper(stop_learner, fw.method = "FSelector_chi.squared")
+  stop.learner = makeFilterWrapper(stop.learner,
+    fw.method = "FSelector_chi.squared")
 
-  stop_learner = makeTuneWrapper(stop_learner, resampling = inner, control = ctrl,
-    par.set = filter_ps, show.info = TRUE)
+  stop.learner = makeTuneWrapper(stop.learner, resampling = inner,
+    control = ctrl,
+    par.set = filter.ps, show.info = TRUE)
 
   warn_learner = makeLearner("classif.__mlrmocklearners__3",
     config = list("on.learner.error" = "warn"))
-  warn_learner = makeFilterWrapper(warn_learner, fw.method = "FSelector_chi.squared")
+  warn_learner = makeFilterWrapper(warn_learner,
+    fw.method = "FSelector_chi.squared")
 
-  warn_learner = makeTuneWrapper(warn_learner, resampling = inner, control = ctrl,
-    par.set = filter_ps, show.info = TRUE)
+  warn_learner = makeTuneWrapper(warn_learner, resampling = inner,
+    control = ctrl,
+    par.set = filter.ps, show.info = TRUE)
 
   # Tests
   # Expect benchmark failing
-  expect_error(benchmark(learners = stop_learner, tasks = task, resamplings = outer,
+  expect_error(benchmark(learners = stop.learner, tasks = task,
+    resamplings = outer,
     keep.pred = FALSE, models = FALSE, show.info = TRUE))
 
   # Expect benchmark warning
-  expect_warning(benchmark(learners = warn_learner, tasks = task, resamplings = outer,
+  expect_warning(benchmark(learners = warn_learner, tasks = task,
+    resamplings = outer,
     keep.pred = FALSE, models = FALSE, show.info = TRUE))
 
   # Expect benchmark messages
