@@ -1,20 +1,17 @@
 context("classif_boosting")
 
-test_that("classif_boosting", {
+# FIXME: Test takes 80s if we test with the default mfinal=100. Without 10s
+# Is there any reasons why testing mfinal=100 would be absolutely necessary?
+
+test_that("classif_boosting rpart control", {
   requirePackagesOrSkip(c("adabag", "rpart"), default.method = "load")
 
   parset.list1 = list(
-    list(control = rpart::rpart.control(xval = 0)),
+    # list(control = rpart::rpart.control(xval = 0)), # mfinal=100
     list(mfinal = 1, control = rpart::rpart.control(xval = 0)),
     list(mfinal = 2, control = rpart::rpart.control(cp = 0.2, xval = 0))
   )
 
-  parset.list2 = list(
-    list(),
-    list(mfinal = 1),
-    list(mfinal = 2, cp = 0.2)
-  )
-
   old.predicts.list = list()
   old.probs.list = list()
 
@@ -30,34 +27,25 @@ test_that("classif_boosting", {
     old.probs.list[[i]] = setColNames(p$prob, levels(multiclass.df[, multiclass.target]))
   }
 
-  testSimpleParsets("classif.boosting", multiclass.df, multiclass.target,
-    multiclass.train.inds, old.predicts.list, parset.list2)
-  testProbParsets("classif.boosting", multiclass.df, multiclass.target,
-    multiclass.train.inds, old.probs.list, parset.list2)
-
-
-  # cv testing with an empty parameter list, takes too long (default mfinal = 100L)
   parset.list2 = list(
+    # list(), # mfinal=100
     list(mfinal = 1),
     list(mfinal = 2, cp = 0.2)
   )
 
-  tt = function(formula, data, subset = seq_len(nrow(data)), ...) {
-    args = list(...)
-    if (!is.null(args$cp)) {
-      ctrl = rpart::rpart.control(cp = args$cp, xval = 0)
-    } else {
-      ctrl = rpart::rpart.control(xval = 0)
-    }
-    set.seed(getOption("mlr.debug.seed"))
-    adabag::boosting(formula, data[subset, ], mfinal = args$mfinal, control = ctrl)
-  }
+  testSimpleParsets("classif.boosting", multiclass.df, multiclass.target,
+    multiclass.train.inds, old.predicts.list, parset.list2)
+  testProbParsets("classif.boosting", multiclass.df, multiclass.target,
+    multiclass.train.inds, old.probs.list, parset.list2)
+})
 
-  tp = function(model, newdata) {
-    set.seed(getOption("mlr.debug.seed"))
-    as.factor(predict(model, newdata)$class)
-  }
+test_that("classif_boosting cv", {
+  # cv testing with an empty parameter list, takes too long (default mfinal = 100L)
+  parset.list3 = list(
+    list(mfinal = 1),
+    list(mfinal = 2, cp = 0.2)
+  )
 
   testCVParsets("classif.boosting", multiclass.df, multiclass.target,
-    tune.train = tt, tune.predict = tp, parset.list = parset.list2)
+    tune.train = boosting_helper1, tune.predict = boosting_helper2, parset.list = parset.list3)
 })
