@@ -2,6 +2,7 @@ context("regr_RRF")
 
 test_that("regr_RRF", {
   requirePackages("RRF", default.method = "load")
+
   parset.list = list(
     list(),
     list(ntree = 5, mtry = 2),
@@ -16,11 +17,10 @@ test_that("regr_RRF", {
     pars = c(pars, parset)
     set.seed(getOption("mlr.debug.seed"))
     m = do.call(RRF::RRF, pars)
-    set.seed(getOption("mlr.debug.seed"))
     p = predict(m, newdata = regr.test, type = "response")
     old.predicts.list[[i]] = p
   }
 
-  testSimpleParsets("regr.RRF", regr.df, regr.target,
-    regr.train.inds, old.predicts.list, parset.list)
+  testSimpleParsets("regr.RRF", regr.df, regr.target, regr.train.inds,
+    old.predicts.list, parset.list)
 })
