@@ -14,15 +14,16 @@ test_that("regr_xgboost", {
     parset = parset.list[[i]]
     if (is.null(parset$verbose)) parset$verbose = 0L
     if (is.null(parset$nrounds)) parset$nrounds = 1L
-    if (is.null(parset$objective)) parset$objective = "reg:linear"
-    pars = list(data = data.matrix(regr.num.train[, -regr.num.class.col]), label = as.numeric(regr.num.train[, regr.num.class.col]))
+    if (is.null(parset$objective)) parset$objective = "reg:squarederror"
+    pars = list(data = data.matrix(regr.num.train[, -regr.num.class.col]),
+      label = as.numeric(regr.num.train[, regr.num.class.col]))
     pars = c(pars, parset)
-    set.seed(getOption("mlr.debug.seed"))
     model = do.call(xgboost::xgboost, pars)
     # model = xgboost::xgboost(data = data.matrix(regr.num.train[,-regr.num.class.col]), verbose = 0L,
     # label = as.numeric(regr.num.train[,regr.num.class.col]),
-    # nrounds = 20, objective = "reg:linear", missing = NULL)
-    old.predicts.list[[i]] = predict(model, data.matrix(regr.num.test[, -regr.num.class.col]))
+    # nrounds = 20, objective = "reg:squarederror", missing = NULL)
+    old.predicts.list[[i]] = predict(model,
+      data.matrix(regr.num.test[, -regr.num.class.col]))
   }
 
   # set.seed(getOption("mlr.debug.seed"))
@@ -31,7 +32,7 @@ test_that("regr_xgboost", {
 })
 
 test_that("xgboost works with different 'missing' arg vals", {
-  lrn = makeLearner("regr.xgboost", missing = NA_real_)
-  lrn = makeLearner("regr.xgboost", missing = NA)
-  lrn = makeLearner("regr.xgboost", missing = NULL)
+  expect_silent(makeLearner("regr.xgboost", missing = NA_real_))
+  expect_silent(makeLearner("regr.xgboost", missing = NA))
+  expect_silent(makeLearner("regr.xgboost", missing = NULL))
 })
