@@ -16,12 +16,11 @@ test_that("surv_glmnet", {
     parset = parset.list[[i]]
     y = as.matrix(surv.train[, surv.target])
     colnames(y) = c("time", "status")
-    pars = c(list(y = Surv(time = surv.train[, surv.target[1]], event = surv.train[, surv.target[2]]),
-      x = as.matrix(surv.train[, -c(1, 2, 7)]), family = "cox"), parset)
+    pars = c(list(y = Surv(time = surv.train[, surv.target[1]],
+      event = surv.train[, surv.target[2]]),
+    x = as.matrix(surv.train[, -c(1, 2, 7)]), family = "cox"), parset)
     glmnet::glmnet.control(factory = TRUE)
-    set.seed(getOption("mlr.debug.seed"))
     ctrl.args = names(formals(glmnet::glmnet.control))
-    set.seed(getOption("mlr.debug.seed"))
     if (any(names(pars) %in% ctrl.args)) {
       on.exit(glmnet::glmnet.control(factory = TRUE))
       do.call(glmnet::glmnet.control, pars[names(pars) %in% ctrl.args])
@@ -29,11 +28,13 @@ test_that("surv_glmnet", {
     } else {
       m = do.call(glmnet::glmnet, pars)
     }
-    p = predict(m, newx = as.matrix(surv.test[, -c(1, 2, 7)]), type = "link", s = 0.01)
+    p = predict(m, newx = as.matrix(surv.test[, -c(1, 2, 7)]), type = "link",
+      s = 0.01)
     old.predicts.list[[i]] = as.numeric(p)
   }
 
-  testSimpleParsets("surv.glmnet", surv.df[, -7], surv.target, surv.train.inds, old.predicts.list, parset.list)
+  testSimpleParsets("surv.glmnet", surv.df[, -7], surv.target, surv.train.inds,
+    old.predicts.list, parset.list)
 
   # check that we restored the factory default
   expect_true(glmnet::glmnet.control()$prec < 1e-4) # should be ==1e-5
